Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(705)

Unified Diff: src/gpu/GrResourceCache2.h

Issue 874693002: Fix the speeling of "purgeable" in Gr code (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/gpu/GrGpuResourceCacheAccess.h ('k') | src/gpu/GrResourceCache2.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/gpu/GrResourceCache2.h
diff --git a/src/gpu/GrResourceCache2.h b/src/gpu/GrResourceCache2.h
index 5aee1add86cc7f055314d5763cb883e912a50e50..d5c418238ba480e9bc3017547b144075520b3b9c 100644
--- a/src/gpu/GrResourceCache2.h
+++ b/src/gpu/GrResourceCache2.h
@@ -155,7 +155,7 @@ private:
////
void insertResource(GrGpuResource*);
void removeResource(GrGpuResource*);
- void notifyPurgable(GrGpuResource*);
+ void notifyPurgeable(GrGpuResource*);
void didChangeGpuMemorySize(const GrGpuResource*, size_t oldSize);
bool didSetContentKey(GrGpuResource*);
void willRemoveScratchKey(const GrGpuResource*);
@@ -230,7 +230,7 @@ private:
// prevents recursive purging
bool fPurging;
- bool fNewlyPurgableResourceWhilePurging;
+ bool fNewlyPurgeableResourceWhilePurging;
PFOverBudgetCB fOverBudgetCB;
void* fOverBudgetData;
@@ -254,9 +254,9 @@ private:
void removeResource(GrGpuResource* resource) { fCache->removeResource(resource); }
/**
* Called by GrGpuResources when they detects that they are newly purgable.
*/
- void notifyPurgable(GrGpuResource* resource) { fCache->notifyPurgable(resource); }
+ void notifyPurgeable(GrGpuResource* resource) { fCache->notifyPurgeable(resource); }
/**
* Called by GrGpuResources when their sizes change.
« no previous file with comments | « src/gpu/GrGpuResourceCacheAccess.h ('k') | src/gpu/GrResourceCache2.cpp » ('j') | no next file with comments »
@@ -254,9 +254,9 @@ private:
void removeResource(GrGpuResource* resource) { fCache->removeResource(resource); }
/**
- * Called by GrGpuResources when they detects that they are newly purgable.
+ * Called by GrGpuResources when they detects that they are newly purgeable.
*/

Powered by Google App Engine
This is Rietveld 408576698